classdef MaximumLikelihood_mod < falcon.parest.costfunction.impl.MaximumLikelihood
    % -------------------------------------------------------------------------
    %                                FALCON.m
    % Copyright (c) 2014-2019 Institute of Flight System Dynamics, TUM, Munich
    % Matthias Bittner, Matthias Rieck, Maximilian Richter,
    % Benedikt Grueter, Johannes Diepolder, Florian Schwaiger,
    % Patrick Piprek, and Florian Holzapfel
    % Downloading, using, copying, or modifying FALCON.m code constitutes an
    % agreement to ALL of the terms of the FALCON.m EULA.
    % -------------------------------------------------------------------------

    % -------------------------------------------------------------------------
    %                                FALCON.m
    % Copyright (c) 2014-2019 Institute of Flight System Dynamics, TUM, Munich
    % Matthias Bittner, Matthias Rieck, Maximilian Richter,
    % Benedikt Grueter, Johannes Diepolder, Florian Schwaiger,
    % Patrick Piprek, and Florian Holzapfel
    % Downloading, using, copying, or modifying FALCON.m code constitutes an
    % agreement to ALL of the terms of the FALCON.m EULA.
    % -------------------------------------------------------------------------

    properties
        % covariance matrix scaling
        CovarianceScalingMatrix
        % scalar scaling factor
        ScalarScaling
        % indicate if output scaling is to be used
        CovarianceScalingMode
    end

    methods
        function ddJ_tilde_ddp_val = ddJ_ddp(obj, meas, model, d_dp)
        % Hessian w.r.t. p
        %  
        % <Syntax>
        % [ ddJ_tilde_ddp ] = ddJ_ddp( z, y, ScalingVector, dy_dp )
        %  
        % <Description>
        % compute the matrix of second cost function derivatives with
        % respect to the parameters for the modified maximum likelihood
        % cost function
        % <Inputs>
        % > z: cell array of measurements
        % > y: cell array of model outputs
        % > Scaling: cell containing scalar scaling value and
        % covariance scaling matrix
        % > dy_dp: output sensitivities w.r.t. the parameters
        %  
        % <Outputs> 
        % > ddJ_tilde_ddp_val: value of the matrix of second cost
        % function derivative
        end

        function ddJ_tilde_dd_val = ddJ_dd(obj, meas, model)
        % compute residual covariance matrix
        end

        function dJ_tilde_d_val = dJ_d(obj, meas, model)
        % cost function derivative w.r.t. y
        %  
        % <Syntax>
        % [ dJ_tilde_dy_val ] = dJ_dy( z, y, ScalingVector, SplineMatrix_fine, SplineMatrix_raw)
        %  
        % <Description>
        % compute the cost function derivatives with respect to the
        % model outputs for the modified maximum likelihood cost
        % function
        % <Inputs>
        % > z: cell array of measurements
        % > y: cell array of model outputs
        % > Scaling: cell containing scalar scaling value and
        % covariance scaling matrix
        % > SplineMatrix_fine: matrix for spline interpolation 
        % > SplineMatrix_raw: matrix for spline interpolation 
        %  
        % <Outputs>
        % > dJ_tilde_dy_val: value of cost function derivative
        end

        function [J_tilde_val, B_scaled_inv] = J(obj, meas, model)
        % cost function value
        %  
        % <Syntax>
        % [ J_tilde_val ] = obj.J( z, y, ScalingVector )
        %  
        % <Description>
        % compute the value of the modified maximum likelihood cost
        % function
        % <Inputs>
        % > z: cell array of measurement values
        % > y: cell array of model output values
        % > Scaling: cell containing scalar scaling value and
        % covariance scaling matrix
        % <Outputs>
        % > J_tilde_val: cost function value
        end

        function obj = MaximumLikelihood_mod(CostFunction)
        % -------------------------------------------------------------------------
        %                                FALCON.m
        % Copyright (c) 2014-2019 Institute of Flight System Dynamics, TUM, Munich
        % Matthias Bittner, Matthias Rieck, Maximilian Richter,
        % Benedikt Grueter, Johannes Diepolder, Florian Schwaiger,
        % Patrick Piprek, and Florian Holzapfel
        % Downloading, using, copying, or modifying FALCON.m code constitutes an
        % agreement to ALL of the terms of the FALCON.m EULA.
        % -------------------------------------------------------------------------
        end

        function dJ_dp_val = dJ_dp(obj, meas, model, d_dp)
        % cost function derivative w.r.t. p
        %  
        % <Syntax>
        % [ dJ_tilde_dp_val ] = dJ_dp( z, y, ScalingVector, dy_dp )
        %  
        % <Description>
        % compute the cost function derivatives with respect to the
        % parameters for the maximum likelihood cost function
        % <Inputs>
        % > z: cell array of measurements
        % > y: cell array of model outputs
        % > Scaling: cell containing scalar scaling value and
        % covariance scaling matrix
        % > dy_dp: output sensitivities w.r.t. the parameters
        %  
        % <Outputs>
        % > dJ_tilde_dp_val: value of the cost function derivative
        end

    end

end