classdef Point < falcon.core.Handle
    % FALCON.TRIM.LIN.POINT linearization point
    %  
    %  	<Description>
    %  	this class contains all information about one linearization point,
    %  	i.e. trim state, control, and output values, together with the
    %  	resulting state-space system and a flag indicating if the point was
    %  	trimmed or not.
    %  
    %  	<ChangeLog>
    %  	2017-12-20 - Ch. Goettlicher: final commenting

    % -------------------------------------------------------------------------
    %                                FALCON.m
    % Copyright (c) 2014-2019 Institute of Flight System Dynamics, TUM, Munich
    % Matthias Bittner, Matthias Rieck, Maximilian Richter,
    % Benedikt Grueter, Johannes Diepolder, Florian Schwaiger,
    % Patrick Piprek, and Florian Holzapfel
    % Downloading, using, copying, or modifying FALCON.m code constitutes an
    % agreement to ALL of the terms of the FALCON.m EULA.
    % -------------------------------------------------------------------------

    properties
        % container for x0
        x0
        % container for xdot0
        xdot0
        % container for u0
        u0
        % container for y0
        y0
        % container for sys object
        sys
        % container for trimmed flag
        trimmed
        % state names from state-space syste
        StateName
        % control names from state-space system
        ControlName
        % output names from state-space system
        OutputName
    end

    methods
        function res = repmat(obj, TargetSize)
        % REPMAT overload repmat function in order to create INDEPENDENT
        %  elements in the ND-array
        %  
        %  	<Syntax>
        %  	[ res ] = repmat( obj, TargetSize )
        %  
        %  	<Description>
        %  	overload repmat function in order to create INDEPENDENT
        %  	elements in the ND-array; standard repmat only creates new
        %  	handles to the same classes.
        %  	here, a new array is created, and only the values explicitly
        %  	copied
        %  
        %  	<Inputs>
        %  	>obj: object array to be expanded
        %  	>TargetSize: array indicating how often obj has to be
        %  	repeated
        %  
        %  	<Outputs>
        %  	>res: the expanded array
        %  
        %  	<ChangeLog>
        %  	2017-03-08 - Ch. Goettlicher: initial design
        %  	2017-12-20 - Ch. Goettlicher: final commenting
        end

        function obj = Point()
        % POINT constructor
        %  
        %  	<Syntax>
        %  	[ obj ] = Point( obj )
        %  
        %  	<Description>
        %  	empty constructor
        %  
        %  	<Outputs>
        %  	>obj: the newly created object
        %  
        %  	<ChangeLog>
        %  	2017-03-08 - Ch. Goettlicher: initial design
        %  	2017-12-20 - Ch. Goettlicher: final commenting
        end

    end

end