classdef Newton < falcon.trim.solver.fsolve
    % FALCON.TRIM.SOLVER.NEWTON newton solver for trim problems
    %  
    %  	<Description>
    %  	implementation of a simple Newton solver for trim problems, using a
    %  	Levenberg-Marquardt stepping algorithm. 
    %  
    %   This solver is NOT able to enforce inequality constraints!
    %  
    %  	<ChangeLog>
    %  	2017-12-20 - Ch. Goettlicher: final commenting

    % -------------------------------------------------------------------------
    %                                FALCON.m
    % Copyright (c) 2014-2019 Institute of Flight System Dynamics, TUM, Munich
    % Matthias Bittner, Matthias Rieck, Maximilian Richter,
    % Benedikt Grueter, Johannes Diepolder, Florian Schwaiger,
    % Patrick Piprek, and Florian Holzapfel
    % Downloading, using, copying, or modifying FALCON.m code constitutes an
    % agreement to ALL of the terms of the FALCON.m EULA.
    % -------------------------------------------------------------------------

    properties
    end

    methods
        function obj = Newton()
        % FALCON.TRIM.SOLVER.NEWTON newton solver for trim problems
        %  
        %  	<Description>
        %  	implementation of a simple Newton solver for trim problems, using a
        %  	Levenberg-Marquardt stepping algorithm. 
        %  
        %   This solver is NOT able to enforce inequality constraints!
        %  
        %  	<ChangeLog>
        %  	2017-12-20 - Ch. Goettlicher: final commenting
        end

        function delete(obj)
        % DELETE clearnup
        %  
        %  	<Syntax>
        %  	delete( obj )
        %  
        %  	<Description>
        %  	perform cleanup operations, e.g. make sure that waitbar is
        %  	closed
        %  
        %  	<Inputs>
        %  	>obj: the TrimSolver object
        %  
        %  	<ChangeLog>
        %  	2017-03-08 - Ch. Goettlicher: initial version
        %  	2017-12-20 - Ch. Goettlicher: final commenting
        end

        function SolverOutput_array = solve(obj, varargin)
        % SOLVE solver call
        %  
        %   <Syntax>
        %   Result = obj.solve( )
        %   Result = obj.solve( TrimProblem )
        %  
        %  	<Description>
        %  	check that a problem to solve is available. Bake it, i.e.
        %  	perform consistency checks and indexing operations and call
        %  	child-class solver routine.
        %  	do so for every grid point, also start animation and waitbar
        %  	during grid trim
        %  
        %  	<Inputs>
        %  	>obj: the TrimSolver object
        %  
        %  	<NameValue>
        %  	>TrimProblem: TrimProblem object to be solved
        %  
        %  	<Outputs>
        %  	>SolverOutput_array: solver specific output struct
        %  
        %  	<ChangeLog>
        %  	2016-12-15 - Ch. Goettlicher: initial version
        %  	2017-02-07 - Ch. Goettlicher: commenting
        %  	2017-03-08 - Ch. Goettlicher: update to grid-trimming
        %  	2017-03-14 - Ch. Goettlicher: update waitbar every 1%
        %  	2017-11-09 - Ch. Goettlicher: implement trim strategy "from
        %                inside out"
        %  	2017-12-20 - Ch. Goettlicher: final commenting
        end

        function setTrimProblem(obj, TrimProblem)
        % SETTRIMPROBLEM set the trim problem
        %  
        %  	<Syntax>
        %  	setTrimProblem( obj, TrimProblem )
        %  
        %  	<Description>
        %  	set reference to a trim problem handle
        %  
        %  	<Inputs>
        %  	>obj: the HasTrimProblem object
        %  	>TrimProblem: the trim problem
        %  
        %  	<ChangeLog>
        %  	2016-12-15 - Ch. Goettlicher: initial version
        %  	2017-02-07 - Ch. Goettlicher: commenting
        %  	2017-12-20 - Ch. Goettlicher: final commenting
        end

    end

end